@@ -26,7 +26,7 @@ sub call {
         my ($token, $params) = $parser->parse($req);
         OAuth::Lite2::Server::Error::InvalidRequest->throw unless $token;
 
-        my $dh = $self->{data_handler}->new(request => $req);
+        my $dh = $self->{data_handler}->new;
 
         my $access_token = $dh->get_access_token($token);
 
